#include <iostream>
#include <string>
#include <algorithm>
#include <vector>

std::string lunaSum(const std::string& a, const std::string& b) {
	std::string result;
	int lengthA = a.size();
	int lengthB = b.size();
	int maxLength = std::max(lengthA, lengthB);
	std::string aPadded = std::string(maxLength - lengthA, '0') + a;
	std::string bPadded = std::string(maxLength - lengthB, '0') + b;
	for (int i = 0; i < maxLength; ++i) {
		result += std::max(aPadded[i], bPadded[i]);
	}
	return result;
}

std::string lunaProduct(const std::string& a, const std::string& b) {
	int lenA = a.length();
	int lenB = b.length();
	std::vector<long long> intermediateResult(lenA + lenB, 0); /

	for (int i = 0; i < lenA; ++i) {
		for (int j = 0; j < lenB; ++j) {
			intermediateResult[i + j] += min(a[lenA - 1 - i] - '0', b[lenB - 1 - j] - '0');
		}
	}

	for (int i = 0; i < intermediateResult.size() - 1; ++i) {
		intermediateResult[i + 1] += intermediateResult[i] / 10;
		intermediateResult[i] %= 10;
	}

	std::string result = "";
	bool leadingZero = true;
	for (int i = intermediateResult.size() - 1; i >= 0; --i) {
		if (intermediateResult[i] != 0 || !leadingZero) {
			leadingZero = false;
			result += to_string(intermediateResult[i]);
		}
	}
	return result.empty() ? "0" : result;
}

int main() {
	std::string a, b;
	std::cin >> a >> b;
	std::string sum = lunaSum(a, b);
	std::string product = lunaProduct(a, b);
	std::cout << sum << "\n" << product << std::endl;
	return 0;
}